# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: vssref_command.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import vssref_common_pb2 as vssref__common__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='vssref_command.proto',
  package='VSSRef.ref_to_team',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=_b('\n\x14vssref_command.proto\x12\x12VSSRef.ref_to_team\x1a\x13vssref_common.proto\"\xa9\x01\n\x0eVSSRef_Command\x12\x1a\n\x04\x66oul\x18\x01 \x01(\x0e\x32\x0c.VSSRef.Foul\x12 \n\tteamcolor\x18\x02 \x01(\x0e\x32\r.VSSRef.Color\x12&\n\x0c\x66oulQuadrant\x18\x03 \x01(\x0e\x32\x10.VSSRef.Quadrant\x12\x11\n\ttimestamp\x18\x04 \x01(\x01\x12\x1e\n\x08gameHalf\x18\x05 \x01(\x0e\x32\x0c.VSSRef.Halfb\x06proto3')
  ,
  dependencies=[vssref__common__pb2.DESCRIPTOR,])




_VSSREF_COMMAND = _descriptor.Descriptor(
  name='VSSRef_Command',
  full_name='VSSRef.ref_to_team.VSSRef_Command',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='foul', full_name='VSSRef.ref_to_team.VSSRef_Command.foul', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='teamcolor', full_name='VSSRef.ref_to_team.VSSRef_Command.teamcolor', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='foulQuadrant', full_name='VSSRef.ref_to_team.VSSRef_Command.foulQuadrant', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='VSSRef.ref_to_team.VSSRef_Command.timestamp', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='gameHalf', full_name='VSSRef.ref_to_team.VSSRef_Command.gameHalf', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=66,
  serialized_end=235,
)

_VSSREF_COMMAND.fields_by_name['foul'].enum_type = vssref__common__pb2._FOUL
_VSSREF_COMMAND.fields_by_name['teamcolor'].enum_type = vssref__common__pb2._COLOR
_VSSREF_COMMAND.fields_by_name['foulQuadrant'].enum_type = vssref__common__pb2._QUADRANT
_VSSREF_COMMAND.fields_by_name['gameHalf'].enum_type = vssref__common__pb2._HALF
DESCRIPTOR.message_types_by_name['VSSRef_Command'] = _VSSREF_COMMAND
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

VSSRef_Command = _reflection.GeneratedProtocolMessageType('VSSRef_Command', (_message.Message,), dict(
  DESCRIPTOR = _VSSREF_COMMAND,
  __module__ = 'vssref_command_pb2'
  # @@protoc_insertion_point(class_scope:VSSRef.ref_to_team.VSSRef_Command)
  ))
_sym_db.RegisterMessage(VSSRef_Command)


# @@protoc_insertion_point(module_scope)
